--[[
NameViolation
v. 1.43
September 16, 2008

* Allows right-clicking on targets to record naming violations.
 (Or just use a keybinding.)
* Also works for names in chat, who list results, etc.
* Supports player, hunter pet and guild names.
* When creating a ticket with 'Report Issue',
  the full report is shown for easy copy and paste.
* Names are automatically removed once reported.
* Fully customizable via interface options.

Future work:
use per-server NameViolation_Names, so any character on server can report
change secure hooks to normal hooks if possible; clean up hooks
consider using friend-like pane for list of names (easier to remove etc)
consider adding statistics (names reported, number, etc.)
consider some kind of detection for whether a reported name is later encountered again

Cannot be done:
setting ticket text without user needing to copy and paste
when user presses ctrl-c, close editbox and return focus to ticket window
]]

-- default settings
local defaults = { };
--defaults.NoResponse = true;
--defaults.SkipTicketWindows = true;
defaults.PetPopup = true;
defaults.TargetPopup = true;
defaults.ChatPopup = true;
defaults.WhoPopup = true;
defaults.FriendPopup = false;
defaults.PartyPopup = false;
defaults.RaidPopup = false;
defaults.GuildPopup = false;
defaults.Guilds = true;
defaults.ShowCategories = true;
defaults.ReportSalutation = NAMEVIOLATION_DEFAULT_SALUTATION;
defaults.ReportOpening = NAMEVIOLATION_DEFAULT_OPENING;
defaults.ReportClosing = NAMEVIOLATION_DEFAULT_CLOSING;

function NameViolation_OnLoad()
	this:RegisterEvent("VARIABLES_LOADED");

	SLASH_NAMEVIOLATION1 = NAMEVIOLATION_SLASH_SHORT;
	SLASH_NAMEVIOLATION2 = NAMEVIOLATION_SLASH_LONG;
	SlashCmdList["NAMEVIOLATION"] = NameViolation_SlashHandler;
	
	-- hooks (explained below)
	UIDropDownMenu_Initialize = NameViolation_UIDropDownMenu_Initialize;
	UIDropDownMenu_AddButton = NameViolation_UIDropDownMenu_AddButton;
	UIDropDownMenu_EnableButton = NameViolation_UIDropDownMenu_EnableButton;
	UnitPopup_HideButtons = NameViolation_UnitPopup_HideButtons;
	UnitPopup_OnClick = NameViolation_UnitPopup_OnClick;
	HelpFrame_OnShow = NameViolation_HelpFrame_OnShow;
	
	if (IsRPServer()) then
		defaults.ReportOpening = NAMEVIOLATION_DEFAULT_OPENING_RP;
	end
	
	-- show report check box when opening ticket window
	local NameViolation_OpenTicketOnShow = function()
		HelpFrame.back = HelpFrameOpenTicketCancel; -- from HelpFrame.xml
		-- only show for "Report Issue" tickets
		if ( HelpFrame.needResponse ) then
			HelpFrameOpenTicketNameViolationShowReport:Hide()
		else
			HelpFrameOpenTicketNameViolationShowReport:Show();
		end
	end
	HelpFrameOpenTicket:SetScript("OnShow", NameViolation_OpenTicketOnShow);
	
	-- close report frame when closing the open ticket window
	local NameViolation_HelpFrameCloseOnClick = function()
		if (HelpFrame.needResponse == false and NameViolationReportFrame:IsVisible()) then
			NameViolationReportFrame:Hide();
		end
		HideUIPanel(this:GetParent());
	end
	HelpFrameCloseButton:SetScript("OnClick", NameViolation_HelpFrameCloseOnClick);
end



function NameViolation_OnEvent()
	if (event == "VARIABLES_LOADED") then
		NameViolation_AddPopUpButtons();
		
		-- prepare settings
		if (not NameViolation_Settings) then
			NameViolation_Settings = {};
		end
		-- any unset settings are set to default
		for k,setting in pairs(defaults) do
			if (NameViolation_Settings[k] == nil) then
				NameViolation_Settings[k] = setting;
			end
		end
		NameViolation_Options_UpdatePopups();
		
		if (not NameViolation_Names) then NameViolation_Names = {}; end
		if (NameViolation_FirstReport == nil) then NameViolation_FirstReport = true; end
		
		-- copy settings for options menu
		NameViolation_OriginalSettings = {};
		for k,setting in pairs(NameViolation_Settings) do
			NameViolation_OriginalSettings[k] = setting;
		end
		NameViolation_Message("ONLOAD");
		if #NameViolation_Names > 1 then
			NameViolation_Message("SIZE",#NameViolation_Names);
		end
	end
end

-- add the "report" button to player, chat and who frame (see UnitPopup.lua)
function NameViolation_AddPopUpButtons()
	UnitPopupButtons["NAME_VIOLATION"] = { text = NAMEVIOLATION_POPUP_BUTTON_NAME, dist = 0 };
	UnitPopupButtons["PET_VIOLATION"] = { text = NAMEVIOLATION_POPUP_BUTTON_NAME, dist = 0 };
	UnitPopupButtons["GUILD_VIOLATION"] = { text = NAMEVIOLATION_POPUP_BUTTON_GUILD, dist = 0 };
	
	-- define whole new menu for pets (normally just treated as RAID_TARGET_ICON)
	UnitPopupMenus["PLAYER_PET"] = { "RAID_TARGET_ICON", "CANCEL" };
	
	-- second-level buttons for category...
	-- RP only
	UnitPopupButtons["NONFANTASY"] = { text = NAMEVIOLATION_POPUP_CATEGORY_NONFANTASY, dist = 0 };
	
	-- obscene or illegal
	UnitPopupButtons["SEXVIOLENCE"] = { text = NAMEVIOLATION_POPUP_CATEGORY_SEXVIOLENCE, dist = 0};
	UnitPopupButtons["ORIENTATION"] = { text = NAMEVIOLATION_POPUP_CATEGORY_ORIENTATION, dist = 0 };
	UnitPopupButtons["ANATOMY"] = { text = NAMEVIOLATION_POPUP_CATEGORY_ANATOMY, dist = 0};
	UnitPopupButtons["DRUGS"] = { text = NAMEVIOLATION_POPUP_CATEGORY_DRUGS, dist = 0 };

	-- reference
	UnitPopupButtons["WELLKNOWN"] = { text = NAMEVIOLATION_POPUP_CATEGORY_WELLKNOWN, dist = 0 };
	UnitPopupButtons["RACE"] = { text = NAMEVIOLATION_POPUP_CATEGORY_RACE, dist = 0 };
	UnitPopupButtons["RELIGION"] = { text = NAMEVIOLATION_POPUP_CATEGORY_RELIGION, dist = 0 };
	UnitPopupButtons["INSULT"] = { text = NAMEVIOLATION_POPUP_CATEGORY_INSULT, dist = 0 };	
	UnitPopupButtons["BLIZZARD"] = { text = NAMEVIOLATION_POPUP_CATEGORY_BLIZZARD, dist = 0 };	
	UnitPopupButtons["LORE"] = { text = NAMEVIOLATION_POPUP_CATEGORY_LORE, dist = 0 };
	UnitPopupButtons["ADVERTISEMENT"] = { text = NAMEVIOLATION_POPUP_CATEGORY_ADVERTISEMENT, dist = 0 };
	UnitPopupButtons["TRADEMARK"] = { text = NAMEVIOLATION_POPUP_CATEGORY_TRADEMARK, dist = 0 };
	
	-- words and letters
	UnitPopupButtons["GIBBERISH"] = { text = NAMEVIOLATION_POPUP_CATEGORY_GIBBERISH, dist = 0 };
	UnitPopupButtons["LEET"] = { text = NAMEVIOLATION_POPUP_CATEGORY_LEET, dist = 0 };
	UnitPopupButtons["TITLE"] = { text = NAMEVIOLATION_POPUP_CATEGORY_TITLE, dist = 0 };
	UnitPopupButtons["SENTENCE"] = { text = NAMEVIOLATION_POPUP_CATEGORY_SENTENCE, dist = 0 };
	
	UnitPopupMenus["NAME_VIOLATION"] = {
		"SEXVIOLENCE", "ORIENTATION", "ANATOMY", "DRUGS",
		"WELLKNOWN", "RACE", "RELIGION", "INSULT", "BLIZZARD", "LORE", "ADVERTISEMENT", "TRADEMARK",
		"GIBBERISH", "LEET", "TITLE", "SENTENCE"
	};

	-- note the removal of "TITLE" (applies to characters only)
	UnitPopupMenus["PET_VIOLATION"] = {
		"SEXVIOLENCE", "ORIENTATION", "ANATOMY", "DRUGS",
		"WELLKNOWN", "RACE", "RELIGION", "INSULT", "BLIZZARD", "LORE", "ADVERTISEMENT", "TRADEMARK",
		"GIBBERISH", "LEET", "SENTENCE"
	};
	
	-- note the removal of "TITLE" (applies to characters only)  and "SENTENCE" (characters and pets only)
	UnitPopupMenus["GUILD_VIOLATION"] = {
		"SEXVIOLENCE", "ORIENTATION", "ANATOMY", "DRUGS",
		"WELLKNOWN", "RACE", "RELIGION", "INSULT", "BLIZZARD", "LORE", "ADVERTISEMENT", "TRADEMARK",
		"GIBBERISH", "LEET"
	};
	
	if (IsRPServer()) then -- add RP server-only stuff
		table.insert(UnitPopupMenus["NAME_VIOLATION"], 1, "NONFANTASY");
		table.insert(UnitPopupMenus["PET_VIOLATION"], 1, "NONFANTASY");
		table.insert(UnitPopupMenus["GUILD_VIOLATION"], 1, "NONFANTASY");
	end
	
	local pos = #UnitPopupMenus["FRIEND"];
	-- always add to friend button, since whether or not it shows depends on open frame etc.
	table.insert(UnitPopupMenus["FRIEND"], pos, "GUILD_VIOLATION");
	table.insert(UnitPopupMenus["FRIEND"], pos, "NAME_VIOLATION");
end

function NameViolation_SlashHandler(msg)
	local cmd, arg = NameViolation_ParseCommand(msg);
	if (cmd == NAMEVIOLATION_CMD_LIST or cmd == NAMEVIOLATION_CMD_LIST2) then
		if (#NameViolation_Names > 0) then
			NameViolation_Message("LIST",#NameViolation_Names);
			for i,v in ipairs(NameViolation_Names) do
				local name = v[1]
				local category = v[2]
				local entryString = i..". |cffffffff"..name.."|r";
				if category ~= nil then
					entryString = entryString .." [|cffff8c00"..category.."|r]";
				end
				NameViolation_Message(entryString);
			end
			--if (#NameViolation_ReportedNames > 0) then
			--	NameViolation_Message("REPORTED_SO_FAR", #NameViolation_ReportedNames);
			--end
		else
			NameViolation_Message("EMPTY");
		end
	elseif (cmd == NAMEVIOLATION_CMD_OPTIONS or cmd == NAMEVIOLATION_CMD_OPTIONS2) then
		PlaySound("igCharacterInfoTab");
		InterfaceOptionsFrame_OpenToFrame(NameViolationOptions);
	elseif (cmd == NAMEVIOLATION_CMD_ADD and arg and arg ~= "") then
		-- name given, so try it (might be character, pet, arena or guild name)
		NameViolation_SaveName(arg);
	elseif ((cmd == NAMEVIOLATION_CMD_REMOVE or cmd == NAMEVIOLATION_CMD_REMOVE2) and arg) then
		NameViolation_RemoveName(tonumber(arg));
	elseif (cmd == NAMEVIOLATION_CMD_CLEAR or cmd == NAMEVIOLATION_CMD_CLEAR2) then
		if #NameViolation_Names > 0 then
			StaticPopup_Show("NAMEVIOLATION_CONFIRMCLEAR");
		else
			NameViolation_Message("EMPTY");
		end
	elseif (cmd == NAMEVIOLATION_CMD_RESET) then
		StaticPopup_Show("NAMEVIOLATION_CONFIRMRESET");
	elseif (cmd == NAMEVIOLATION_CMD_LANGUAGE) then
		-- @@@ should be dropdown in options menu, not command
		NameViolation_UpdateReportLanguage();
	elseif (cmd == NAMEVIOLATION_CMD_HELP) then
		-- display instructions
		for i,line in ipairs(NAMEVIOLATION_MSG.USAGE) do
			NameViolation_Message(line);
		end	
	else
		-- display available commands
		for i,line in ipairs(NAMEVIOLATION_MSG.COMMANDS) do
			NameViolation_Message(line);
		end
	end
end

function NameViolation_SaveName(name, category)
	-- category may be nil
	if (name ~= nil and name ~= "") then
		local index = NameViolation_Exists(name);
		if (not index or category ~= NameViolation_Names[index][2]) then
			local entry = {name, category}
			if (index) then
				-- entry exists, but with different category, so update it
				table.remove(NameViolation_Names, index);
				table.insert(NameViolation_Names, index, entry);
				if (category) then
					NameViolation_Message("UPDATED_CAT", name, category);
				else
					NameViolation_Message("UPDATED", name);
				end
			else
				table.insert(NameViolation_Names, entry);
				if (category) then
					NameViolation_Message("ADDED_CAT", name, category);
				else
					NameViolation_Message("ADDED", name);
				end
				if (NameViolation_FirstReport) then
					-- display report instructions etc.
					for i,line in ipairs(NAMEVIOLATION_MSG.FIRST_REPORT) do
						NameViolation_Message(line);
					end
					NameViolation_FirstReport = false;
				end
			end
		else
			NameViolation_Message("ALREADY", name);
		end
	end
end

function NameViolation_RemoveName(pos)
	if (pos and pos > 0 and pos <= #NameViolation_Names) then
		local name = NameViolation_Names[pos][1];
		if (name) then
			table.remove(NameViolation_Names, pos);
			NameViolation_Message("REMOVED", name);
		else
			NameViolation_Message("NOT_REMOVED");
		end
	else
		NameViolation_Message("NOT_REMOVED");
	end
end

function NameViolation_ResetOptions()
	NameViolation_Settings = {};
	for k,setting in pairs(defaults) do
		NameViolation_Settings[k] = setting;
	end
	NameViolation_Options_UpdatePopups();
end

-- hooks for adding titles in category submenus
local Original_UIDropDownMenu_AddButton = UIDropDownMenu_AddButton;
local Original_UIDropDownMenu_EnableButton = UIDropDownMenu_EnableButton;
function NameViolation_UIDropDownMenu_AddButton(info, ...)
	if (NameViolation_CheckedCategory and
		info.value == NameViolation_CheckedCategory[1] and
		info.owner == NameViolation_CheckedCategory[2]) then
		info.checked = 1;
	end
	if (NameViolation_Settings and NameViolation_Settings.ShowCategories) then
		-- add titles in NameViolation etc. submenus
		if info.value == "NONFANTASY" then
			local titleInfo = { notCheckable = 1, text = NAMEVIOLATION_POPUP_CATEGORY_GROUP_RP, isTitle = 1 }
			UIDropDownMenu_AddButton(titleInfo, 2)
		elseif info.value == "SEXVIOLENCE" then
			local titleInfo = { notCheckable = 1, text = NAMEVIOLATION_POPUP_CATEGORY_GROUP_OBSCENE, isTitle = 1 }
			UIDropDownMenu_AddButton(titleInfo, 2)		
		elseif info.value == "WELLKNOWN" then
			local titleInfo = { notCheckable = 1, text = NAMEVIOLATION_POPUP_CATEGORY_GROUP_REFERENCE, isTitle = 1 }
			UIDropDownMenu_AddButton(titleInfo, 2)
		elseif info.value == "GIBBERISH" then
			local titleInfo = { notCheckable = 1, text = NAMEVIOLATION_POPUP_CATEGORY_GROUP_WORDS, isTitle = 1 }
			UIDropDownMenu_AddButton(titleInfo, 2)
		end
	end
	Original_UIDropDownMenu_AddButton(info, ...)
end

function NameViolation_UIDropDownMenu_EnableButton(level, id)
	-- prevent enabling titles (seems to be no better way, since by default only 1 title per menu)
	if (NameViolation_Settings.ShowCategories) then
		local menuValue = UIDROPDOWNMENU_MENU_VALUE;
		local text = getglobal("DropDownList"..level.."Button"..id).value;
		if (
				(menuValue == "NAME_VIOLATION" or menuValue == "PET_VIOLATION" or menuValue == "GUILD_VIOLATION")
				and	(
					text == NAMEVIOLATION_POPUP_CATEGORY_GROUP_RP or
					text == NAMEVIOLATION_POPUP_CATEGORY_GROUP_OBSCENE or
					text == NAMEVIOLATION_POPUP_CATEGORY_GROUP_REFERENCE or
					text == NAMEVIOLATION_POPUP_CATEGORY_GROUP_WORDS
					)
			) then
			return; -- don't enable
		end
	end
	Original_UIDropDownMenu_EnableButton(level, id);
end

-- hook for treating pets as more than just icon bearers
local Original_UIDropDownMenu_Initialize = UIDropDownMenu_Initialize;
function NameViolation_UIDropDownMenu_Initialize(frame, initFunction, displayMode, level, menuList)
	-- seems to be no better way to accomplish this
	if (not NameViolation_Settings or not NameViolation_Settings.PetPopup) then
		-- just call original
		Original_UIDropDownMenu_Initialize(frame, initFunction, displayMode, level, menuList);
	else
		local pet = false;
		if (initFunction == TargetFrameDropDown_Initialize) then
			if (NameViolation_TargetIsPet()) then
					pet = true;
					initFunction = nil; -- set to nil to avoid double menus appearing
			end
		end
		Original_UIDropDownMenu_Initialize(frame, initFunction, displayMode, level, menuList);
		if (pet) then	
			UnitPopup_ShowMenu(TargetFrameDropDown, "PLAYER_PET", "target", name, id);
		end
	end
end


function NameViolation_SetCheckedCategory(index)
	local categoryText = NameViolation_Names[index][2];
	if (categoryText) then
		for k,v in pairs(NAMEVIOLATION_CATEGORIES) do
			if (v == categoryText) then
				-- set temporary global
				NameViolation_CheckedCategory = { k, UIDROPDOWNMENU_MENU_VALUE };
				break;
			end
		end
	end
end

-- hook to show/hide guild button (called whenever unitpop is shown)
local Original_UnitPopup_HideButtons = UnitPopup_HideButtons;
function NameViolation_UnitPopup_HideButtons()
	Original_UnitPopup_HideButtons();

	local dropdownMenu = getglobal(UIDROPDOWNMENU_INIT_MENU);
	local which = dropdownMenu.which;

	if (select(2,IsInInstance()) == "pvp") then
		-- in arena or battleground, so hide all buttons
		local ni, gi = NameViolation_GetPopupMenuIndices(which);
		if (ni) then
			UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][ni] = 0;
		end
		if (gi) then
			UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][gi] = 0;
		end
	end
	
	NameViolation_CheckedCategory = nil;
	if (UIDROPDOWNMENU_MENU_VALUE == "NAME_VIOLATION") then
		local index = NameViolation_Exists(dropdownMenu.name);
		if (index) then
			-- set check for name violation menu
			NameViolation_SetCheckedCategory(index);
		end
	elseif (UIDROPDOWNMENU_MENU_VALUE == "GUILD_VIOLATION") then
		local index = NameViolation_Exists(GUILD_NAME.." ("..GUILD..")");
		if (index) then
			-- set check for guild violation menu
			NameViolation_SetCheckedCategory(index);
		end
	elseif (UIDROPDOWNMENU_MENU_VALUE == "PET_VIOLATION") then
		local owner = "(" .. NameViolation_GetTooltip() .. ")";
		local index = NameViolation_Exists(dropdownMenu.name .. " " .. owner);
		if (index) then
			-- set check for guild violation menu
			NameViolation_SetCheckedCategory(index);
		end
	end	
	
	if (which == "PLAYER" or which == "PARTY" or which == "RAID_PLAYER") then
		-- name violation button is shown by default, so just consider guild button
		if (NameViolation_Settings.Guilds and NameViolation_Settings.TargetPopup ) then
			if  (
				(which == "PARTY" and not NameViolation_Settings.PartyPopup) or
				(which == "RAID_PLAYER" and not NameViolation_Settings.RaidPopup)
				) then return; -- no buttons anyway, so skip rest
			end
			-- check if unit is in a guild
			local guild, _, _ = GetGuildInfo(dropdownMenu.unit);
			if (guild) then
				GUILD_NAME = guild; -- save global
			else
				local _, gi = NameViolation_GetPopupMenuIndices(which);
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][gi] = 0;
			end
		end
	elseif (which == "FRIEND") then
		local ni, gi = NameViolation_GetPopupMenuIndices(which);
		if (dropdownMenu.lineID) then
			-- always hide guild button for chat (user can't see guild names)
			UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][gi] = 0;
			if (not NameViolation_Settings.ChatPopup) then
				-- chat disabled, so hide even name button
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][ni] = 0;
			end
		elseif (WhoFrame:IsShown())	then
			if (not NameViolation_Settings.WhoPopup) then
				-- hide both
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][ni] = 0;
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][gi] = 0;
			else
				-- keep name button visible
				if (not NameViolation_Settings.Guilds
					or UIDropDownMenu_GetSelectedID(WhoFrameDropDown) ~= 2) then
					-- hide guild button if guilds disabled or if guild names not shown in list
					UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][gi] = 0;
				else
					-- no unit available for GetGuildInfo(unit), so have to read from list...
					-- get proper index even if frame scrolled
					if (UIDROPDOWNMENU_MENU_LEVEL ~= 2) then
						-- guild already checked, and GetID() problematic at this level
						local whoIndex = this:GetID() + FauxScrollFrame_GetOffset(WhoListScrollFrame); 
						local _, guild, _, _, _, _, _ = GetWhoInfo(whoIndex);
						if (guild and guild ~= "") then
							GUILD_NAME = guild; -- save global
						else
							-- selected person not in a guild, so hide button
							UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][gi] = 0;
						end
					end
				end
			end
		elseif (GuildFrame:IsShown()) then
			-- wouldn't want to report your own guild name, so hide button
			UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][gi] = 0;
			if (not NameViolation_Settings.GuildPopup) then
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][ni] = 0;
			end	
		elseif (FriendsListFrame:IsShown()) then
			-- always hide guild button for friends (user can't see guild names)
			UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][gi] = 0;
			if (not NameViolation_Settings.FriendPopup) then
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][ni] = 0;
			end	
		end
	end
end

-- hook for handling clicks on violation buttons
local Original_UnitPopup_OnClick = UnitPopup_OnClick;
function NameViolation_UnitPopup_OnClick()
	Original_UnitPopup_OnClick();
	local dropdownFrame = getglobal(UIDROPDOWNMENU_INIT_MENU);
	local menuValue = UIDROPDOWNMENU_MENU_VALUE;
	if (strsub(this.value,1,14) == "NAME_VIOLATION") then
		NameViolation_SaveName(dropdownFrame.name)
	elseif (menuValue == "NAME_VIOLATION" and tContains(UnitPopupMenus["NAME_VIOLATION"], this.value)) then
		NameViolation_SaveName(dropdownFrame.name, NAMEVIOLATION_CATEGORIES[this.value])
	elseif (strsub(this.value,1,13) == "PET_VIOLATION") then
		--  sadly, only way to get owner is with a tooltip: http://www.worldofwar.net/forums/archive/index.php/t-372677.html
		local owner = "(" .. NameViolation_GetTooltip() .. ")";
		NameViolation_SaveName(dropdownFrame.name .. " " .. owner);
	elseif (menuValue == "PET_VIOLATION" and tContains(UnitPopupMenus["PET_VIOLATION"], this.value)) then
		local owner = "(" .. NameViolation_GetTooltip() .. ")";
		NameViolation_SaveName(dropdownFrame.name .. " " .. owner, NAMEVIOLATION_CATEGORIES[this.value]);
	elseif (strsub(this.value,1,15) == "GUILD_VIOLATION") then
			-- guild name saved as global from when unitpop shown
			NameViolation_SaveName(GUILD_NAME.." ("..GUILD..")");
			--GUILD_NAME = ""; -- reset global
	elseif (menuValue == "GUILD_VIOLATION" and tContains(UnitPopupMenus["GUILD_VIOLATION"], this.value)) then
			NameViolation_SaveName(GUILD_NAME.." ("..GUILD..")", NAMEVIOLATION_CATEGORIES[this.value]);
			--GUILD_NAME = ""; -- reset global
	end
end

-- hook for determining default value of show report checkbutton 
local Original_HelpFrame_OnShow = HelpFrame_OnShow;
function NameViolation_HelpFrame_OnShow()
	Original_HelpFrame_OnShow();
	
	-- set to checked by default only if there are names to be reported
	if (#NameViolation_Names > 0) then
		HelpFrameOpenTicketNameViolationShowReport:SetChecked(1);
	else
		HelpFrameOpenTicketNameViolationShowReport:SetChecked(0);
	end
end



-- needs to be updated if localized to additional languages
-- note that this will set report options to defaults (in new language), but doesn't update categories of existing names
-- @@@ fix repetition of globals... use function to set globals instead
function NameViolation_UpdateReportLanguage()
	local current;
	if (NameViolation_Settings.ReportLanguage) then
		current = NameViolation_Settings.ReportLanguage;
	else
		current = GetLocale();
	end
	if (current == "enUS") then
		-- switch reports to German
		NameViolation_Settings.ReportLanguage = "deDE";

		-- set to defaults
		NameViolation_Settings.ReportSalutation = "Lieber GameMaster,";
		if (IsRPServer()) then
			NameViolation_Settings.ReportOpening = "Die folgenden Namen verletzen die Namensbestimmungen und/oder die Rollenspielbestimmungen:"
		else
			NameViolation_Settings.ReportOpening = "Die folgenden Namen verletzen die Namensbestimmungen:";
		end
		NameViolation_Settings.ReportClosing = "Danke f\195\188r deine Zeit,";
		--NAMEVIOLATION_REPORT_PS = "P.S. Ich ben\195\182tige keine Antwort auf dieses Ticket.";
		
		-- use German category names from now on
		NAMEVIOLATION_CATEGORIES.RACE = "Rasse/Ethnische Gruppen";
		NAMEVIOLATION_CATEGORIES.SEXVIOLENCE = "Sexuelle Gewalt/Gewaltverherrlichend";
		NAMEVIOLATION_CATEGORIES.ORIENTATION = "Sexuelle Ausrichtung";
		NAMEVIOLATION_CATEGORIES.ANATOMY = "Obsz\195\182n/Vulg\195\164r";
		NAMEVIOLATION_CATEGORIES.INSULT = "Bel\195\164stigung/Diffamierung";
		NAMEVIOLATION_CATEGORIES.RELIGION = "Religi\195\182ses/Politik";
		NAMEVIOLATION_CATEGORIES.BLIZZARD = "Blizzard Mitarbeiter";
		NAMEVIOLATION_CATEGORIES.DRUGS = "Illegale Droge/Aktivit\195\164t";
		NAMEVIOLATION_CATEGORIES.ADVERTISEMENT = "Werbung";
		NAMEVIOLATION_CATEGORIES.TRADEMARK = "Lizenziertes/Markenname";
		NAMEVIOLATION_CATEGORIES.GIBBERISH = "Kauderwelsch";
		NAMEVIOLATION_CATEGORIES.TITLE = "Titel";
		NAMEVIOLATION_CATEGORIES.SENTENCE = "Satz/Satzteil";
		NAMEVIOLATION_CATEGORIES.WELLKNOWN = "Bekannte Person/Ort";
		NAMEVIOLATION_CATEGORIES.LEET = "Leet Sprache";
		NAMEVIOLATION_CATEGORIES.NONFANTASY = "Unangemessen";
		NAMEVIOLATION_CATEGORIES.LORE = "Warcraft Geschichte";

		if (GetLocale() == "deDE") then
			NameViolation_Message("LANGUAGE","Deutschen");
		else
			NameViolation_Message("LANGUAGE","German");
		end
	else
		-- switch reports to English
		NameViolation_Settings.ReportLanguage = "enUS";
		
		-- set to defaults
		NameViolation_Settings.ReportSalutation = "Dear Game Master,";
		if (IsRPServer()) then
			NameViolation_Settings.ReportOpening = "The following name(s) violate the Naming Policy and/or the Roleplaying Policy:"
		else
			NameViolation_Settings.ReportOpening = "The following name(s) violate the Naming Policy:";
		end
		NameViolation_Settings.ReportClosing = "Thank you for looking into this,";
		--NAMEVIOLATION_REPORT_PS = "P.S. I do not require a response to this ticket.";

		-- use English category names from now on
		NAMEVIOLATION_CATEGORIES.RACE = "Racial/Ethnic/National";
		NAMEVIOLATION_CATEGORIES.SEXVIOLENCE = "Sexuality/Violence";
		NAMEVIOLATION_CATEGORIES.ORIENTATION = "Sexual Orientation";
		NAMEVIOLATION_CATEGORIES.ANATOMY = "Obscene/Vulgar";
		NAMEVIOLATION_CATEGORIES.INSULT = "Harassing/Defamatory";
		NAMEVIOLATION_CATEGORIES.RELIGION = "Religion/Religious Figure";
		NAMEVIOLATION_CATEGORIES.BLIZZARD = "Blizzard Employee";
		NAMEVIOLATION_CATEGORIES.DRUGS = "Illegal Drug/Activity";
		NAMEVIOLATION_CATEGORIES.ADVERTISEMENT = "Advertising";
		NAMEVIOLATION_CATEGORIES.TRADEMARK = "Trademark";
		NAMEVIOLATION_CATEGORIES.GIBBERISH = "Pure Gibberish";
		NAMEVIOLATION_CATEGORIES.TITLE = "Title";
		NAMEVIOLATION_CATEGORIES.SENTENCE = "Partial/Complete Sentence";
		NAMEVIOLATION_CATEGORIES.WELLKNOWN = "Real World Reference";
		NAMEVIOLATION_CATEGORIES.LEET = "Leet speak";
		NAMEVIOLATION_CATEGORIES.NONFANTASY = "Non-Medieval/Fantasy";
		NAMEVIOLATION_CATEGORIES.LORE = "Warcraft Lore";
		
		if (GetLocale() == "deDE") then
			NameViolation_Message("LANGUAGE","Englisch");
		else
			NameViolation_Message("LANGUAGE","English");
		end
	end
end